"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildDecorations = exports.buildHighlightInfo = exports.terms = void 0;
const monaco_1 = require("./monaco");
exports.terms = [
    "type",
    "scope",
    "function",
    "variable",
    "number",
    "string",
    "comment",
    "constant",
    "directive",
    "control",
    "operator",
    "modifier",
    "punctuation"
];
function buildHighlightInfo(tree, language) {
    const result = [];
    const stack = [];
    let node = tree.rootNode.firstChild;
    while (stack.length > 0 || node) {
        if (node) {
            stack.push(node);
            node = node.firstChild;
        }
        else {
            node = stack.pop();
            let type = node.type;
            if (!node.isNamed())
                type = '"' + type + '"';
            let term = null;
            if (!language.complexTerms.includes(type)) {
                term = language.simpleTerms[type];
            }
            else {
                let desc = type;
                let scopes = [desc];
                let parent = node.parent;
                for (let i = 0; i < language.complexDepth && parent; i++) {
                    let parentType = parent.type;
                    if (!parent.isNamed())
                        parentType = '"' + parentType + '"';
                    desc = parentType + " > " + desc;
                    scopes.push(desc);
                    parent = parent.parent;
                }
                if (language.complexOrder) {
                    let index = 0;
                    let sibling = node.previousSibling;
                    while (sibling) {
                        if (sibling.type === node.type)
                            index++;
                        sibling = sibling.previousSibling;
                    }
                    let rindex = -1;
                    sibling = node.nextSibling;
                    while (sibling) {
                        if (sibling.type === node.type)
                            rindex--;
                        sibling = sibling.nextSibling;
                    }
                    const orderScopes = [];
                    for (let i = 0; i < scopes.length; i++)
                        orderScopes.push(scopes[i], scopes[i] + "[" + index + "]", scopes[i] + "[" + rindex + "]");
                    scopes = orderScopes;
                }
                for (const d of scopes)
                    if (d in language.complexScopes)
                        term = language.complexScopes[d];
            }
            if (exports.terms.includes(term)) {
                result.push({ term, node });
            }
            node = node.nextSibling;
        }
    }
    return result;
}
exports.buildHighlightInfo = buildHighlightInfo;
function buildDecorations(tree, language) {
    if (!monaco_1.Monaco)
        throw new TypeError("Please provide the monaco-editor module via provideMonacoModule() first.");
    const decorations = Object.fromEntries(exports.terms.map(term => [term, []]));
    const highlightInfo = buildHighlightInfo(tree, language);
    for (const { term, node } of highlightInfo) {
        decorations[term].push(new monaco_1.Monaco.Range(node.startPosition.row + 1, node.startPosition.column + 1, node.endPosition.row + 1, node.endPosition.column + 1));
    }
    return decorations;
}
exports.buildDecorations = buildDecorations;
//# sourceMappingURL=highlighter.js.map