"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Theme = void 0;
const monaco_1 = require("./monaco");
class Theme {
    constructor() { }
    static load(config) {
        if (monaco_1.Monaco) {
            monaco_1.Monaco.editor.defineTheme("monaco-tree-sitter", config.base);
            monaco_1.Monaco.editor.setTheme("monaco-tree-sitter");
        }
        if (!this.tag) {
            this.tag = document.createElement("style");
            document.head.appendChild(this.tag);
        }
        this.config = config;
        this.tag.innerHTML = this.generateCss();
    }
    static generateCss(classNamePrefix = this.cssClassNamePrefix) {
        return Object.keys(this.config.monacoTreeSitter)
            .map((term) => `span.${this.getClassNameOfTerm(term, classNamePrefix)}{${this.generateStyleOfTerm(term)}}`)
            .join("");
    }
    static generateStyleOfTerm(term) {
        const style = this.config.monacoTreeSitter[term];
        if (!style)
            return "";
        return typeof style === "string"
            ? `color:${style}`
            : `color:${style.color};${style.extraCssStyles ? style.extraCssStyles : ""}`;
    }
    static getClassNameOfTerm(term, classNamePrefix = this.cssClassNamePrefix) {
        return classNamePrefix + term;
    }
    static getColorOfTerm(term) {
        const style = this.config.monacoTreeSitter[term];
        if (typeof style === "object") {
            return style.color;
        }
        else {
            return style;
        }
    }
}
exports.Theme = Theme;
Theme.cssClassNamePrefix = "mts-";
//# sourceMappingURL=theme.js.map